@@ -7,12 +7,16 @@ from dswizard.components.util import HANDLES_NOMINAL_CLASS, HANDLES_MISSING, HAN
 
 class NormalizerComponent(PreprocessingAlgorithm):
     def __init__(self, norm: str = 'l2'):
-        super().__init__()
+        super().__init__('normalize')
         self.norm = norm
 
     def to_sklearn(self, n_samples: int = 0, n_features: int = 0, **kwargs):
         from sklearn.preprocessing import Normalizer
-        return Normalizer(norm=self.norm, copy=False)
+        return Normalizer(norm=self.norm)
+
+    def get_feature_names_out(self, input_features: list[str] = None):
+        from sklearn.utils.validation import _check_feature_names_in
+        return _check_feature_names_in(self, input_features)
 
     @staticmethod
     def get_hyperparameter_search_space(**kwargs):
