@@ -8,13 +8,13 @@ from dswizard.components.util import HANDLES_NOMINAL_CLASS, HANDLES_MISSING, HAN
 class StandardScalerComponent(PreprocessingAlgorithm):
 
     def __init__(self, with_mean: bool = True, with_std: bool = True):
-        super().__init__()
+        super().__init__('standard_scaler')
         self.with_mean = with_mean
         self.with_std = with_std
 
     def to_sklearn(self, n_samples: int = 0, n_features: int = 0, **kwargs):
         from sklearn.preprocessing import StandardScaler
-        return StandardScaler(with_std=self.with_std, with_mean=self.with_mean, copy=False)
+        return StandardScaler(with_std=self.with_std, with_mean=self.with_mean)
 
     @staticmethod
     def get_hyperparameter_search_space(**kwargs):
