@@ -1,6 +1,5 @@
 import numpy as np
 from ConfigSpace.configuration_space import ConfigurationSpace
-from ConfigSpace.hyperparameters import CategoricalHyperparameter
 
 from dswizard.components.base import PreprocessingAlgorithm
 from dswizard.components.util import HANDLES_NOMINAL_CLASS, HANDLES_MISSING, HANDLES_NOMINAL, HANDLES_NUMERIC, \
@@ -8,8 +7,13 @@ from dswizard.components.util import HANDLES_NOMINAL_CLASS, HANDLES_MISSING, HAN
 
 
 class MissingIndicatorComponent(PreprocessingAlgorithm):
-    def __init__(self, missing_values=np.nan, features: str = "missing-only"):
-        super().__init__()
+    def __init__(self, missing_values=np.nan, features: str = "all"):
+        super().__init__('missing_indicator')
+        try:
+            if np.isnan(missing_values):
+                self.args['missing_values'] = 'NaN'
+        except TypeError:
+            pass
 
         self.features = features
         self.missing_values = missing_values
@@ -18,6 +22,15 @@ class MissingIndicatorComponent(PreprocessingAlgorithm):
         from sklearn.impute import MissingIndicator
         return MissingIndicator(missing_values=self.missing_values, features=self.features)
 
+    def transform(self, X):
+        if self.estimator_ is None:
+            raise ValueError()
+        missing = self.estimator_.transform(X)
+        return np.any(missing, axis=1, keepdims=True).astype(int)
+
+    def get_feature_names_out(self, input_features: list[str] = None):
+        return np.array(['missing_values'])
+
     @staticmethod
     def get_properties():
         return {'shortname': 'Imputation',
@@ -27,11 +40,14 @@ class MissingIndicatorComponent(PreprocessingAlgorithm):
                 HANDLES_NOMINAL: True,
                 HANDLES_MISSING: True,
                 HANDLES_NOMINAL_CLASS: True}
+    
+    @staticmethod
+    def deserialize(**kwargs) -> 'MissingIndicatorComponent':
+        if 'missing_values' in kwargs and kwargs['missing_values'] == 'NaN':
+            kwargs['missing_values'] = np.nan
+        return MissingIndicatorComponent(**kwargs)
 
     @staticmethod
     def get_hyperparameter_search_space(**kwargs):
-        features = CategoricalHyperparameter("features", ["missing-only", "all"], default_value="missing-only")
-
         cs = ConfigurationSpace()
-        cs.add_hyperparameters([features])
         return cs
